// Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#pragma once

#include "opencv2/imgproc/imgproc.hpp"
#include "ultra_infer/vision/common/result.h"

namespace ultra_infer {
namespace vision {

cv::Mat VisSegmentationNEON(const cv::Mat &im, const SegmentationResult &result,
                            float weight, bool quantize_weight = true);

} // namespace vision
} // namespace ultra_infer
