# Copyright (c) 2024 PaddlePaddle Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .. import download
from . import hub_env


def get_detection_test_image(path=None):
    if path is None:
        path = hub_env.RESOURCE_HOME
    fullpath = download(
        url="https://bj.bcebos.com/paddlehub/fastdeploy/example/detection_test_image.jpg",
        path=path,
    )
    return fullpath
